package examples.keyedfile;

/**
 * IBM Confidential                                                  
 * OCO Source Materials                                              
 * Satin Data Integration Toolkit
 * Prog License number                                               
 * (C) Copyright IBM Corp. 2002                                      
 * The source code for this program is not published or              
 * otherwise divested of its trade secrets, irrespective of          
 * what has been deposited with the US Copyright Office.             
 */

import com.ibm.OS4690.*;

/**
 * Make a keyed file.
 * <p>
 * This is a simple class that creates and populates a keyed file
 * with some records.  All values except the keyed file name are
 * hardcoded for simplicity.
 * @author Dan Streetman
 */
public class MakeKeyedFile
{
	public static void main(String[] argv) throws Exception
	{
		int keyLength = 4;
		int recordSize = 16;

		if (argv.length < 1 || argv.length > 3) {
			System.err.println("Usage :\n\tjava examples.MakeKeyedFile <filename> [keyLength] [recordSize]");
			System.exit(1);
		}

		if (argv.length > 1)
			keyLength = Integer.decode(argv[1]).intValue();

		if (argv.length > 2)
			recordSize = Integer.decode(argv[2]).intValue();

		KeyedFile kF = new KeyedFile(argv[0], "rw", KeyedFile.SHARED_READ_WRITE_ACCESS, keyLength, recordSize, 1024, 1, 128);

		System.out.println("Created KeyedFile " + argv[0] + " with key length " + keyLength + " and record size " + recordSize);

		if (16 == recordSize && 4 == keyLength) {
			byte[][] records = {
				"1234000099998888".getBytes(),
				"9876mnbvcxzlkasd".getBytes(),
				"qqqq123456789012".getBytes(),
				"1111qqqqwwwweeee".getBytes(),
				"2222zaqwxscderfv".getBytes(),
				"3333poiuytrewqas".getBytes(),
			};

			for (int i=0; i<records.length; i++) {
				System.out.println("Writing record (size " + records[i].length + ") to keyed file : " + new String(records[i]));
				try {
					kF.write(records[i], KeyedFile.NO_UNLOCK, KeyedFile.NO_HOLD);
					System.out.println("Wrote record to keyed file.");
				} catch ( Exception e ) {
					System.out.println("Exception writing record to keyed file : " + e.toString());
				}
			}
		}

		kF.closeFull();
	}
}
