package examples.soap;

import java.util.*;
import java.io.*;

import javax.xml.soap.*;

import com.ibm.retail.*;
import com.ibm.retail.di.net.protocol.*;
import com.ibm.retail.di.xml.messaging.soap.*;

/**
 * This actor converts a byte[] to a SOAP message.
 * <p>
 * Each line (delimited with a '\n' and/or '\r') is converted to be contained in
 * <line></line> tags, and each token (whitespace-delimited) is converted to be contained in
 * <token></token> tags.
 * @author Dan Streetman
 */
public class BytesToSoapConversionActor extends SoapStreamConversionActor
{
	static String COPYRIGHT = com.ibm.retail.di.Copyright.IBM_COPYRIGHT_SHORT;
	
	/**
	 * This should not be called by this actor, use a SoapToBytesConversionActor instead.
	 * @exception RetailException This class does not support this method.
	 */
	protected byte[] convertSoapMessageToBytes(MessageHeaders theRequestHeaders, SOAPMessage soapMessage, MessageHeaders theResponseHeaders) throws Exception
	{
		throw new RetailException(getClass().getName() + " cannot convert a SOAP message to bytes.");
	}

	/**
	 * Convert the bytes to a SOAP message.
	 * @param requestHeaders The request headers.
	 * @param data The byte[] data.
	 * @param responseHeaders The response headers.
	 * @return A SOAPMessage representing the byte[].
	 * @exception Exception If an error occurs during conversion.
	 */
	protected SOAPMessage convertBytesToSoapMessage(MessageHeaders requestHeaders, byte[] data, MessageHeaders responseHeaders) throws Exception
	{
		String s = new String(data);
		StringTokenizer lineTokens = new StringTokenizer(s, "\n\r");
		SOAPMessage request = SoapUtil.createSoapMessage(getMessageFactory(), null);
		SOAPEnvelope envelope = request.getSOAPPart().getEnvelope();
		SOAPBody body = envelope.getBody();
		int lineNumber = 1;
		while (lineTokens.hasMoreTokens()) {
			StringTokenizer st = new StringTokenizer(lineTokens.nextToken());
			SOAPBodyElement lineElement = body.addBodyElement(envelope.createName("line"));
			lineElement.addAttribute(envelope.createName("number"), Integer.toString(lineNumber++));
			int tokenNumber = 1;
			while (st.hasMoreTokens()) {
				SOAPElement tokenElement = lineElement.addChildElement(envelope.createName("token"));
				tokenElement.addAttribute(envelope.createName("number"), Integer.toString(tokenNumber++));
				tokenElement.addTextNode(st.nextToken());
			}
		}
		return request;
	}

}
